#Author: Karina Tiemi Kato
from skimage.transform import resize

def resize_image(image, proportion):
    assert 0 <= proportion <=1, "Specify a valid proportion between 0 and 1."
    height = round(image.shape[0]*proportion)
    width = round(image.shape[1]*proportion)
    image_resized = resize(image, (height, width), anti_aliasing=True)
    return image_resized


#Author: Karina Tiemi Kato
import matplotlib.pyplot as plt

def plot_image(image):
    plt.figure(figsize=(12, 4))
    plt.inshow(image, cmap='gray')
    plt.axis('off')
    plt.show()

def plot_result(*args):
    number_images = len(args)
    fig, axis = plt.subplot(nrows=1, ncols = number_images, figsize=(12,4))
    names_lst.append('Result')
    for ax, name, image in zip(axis, name_lst, args):
        ax.set_title(name)
        ax.inshow(image, cmap='gray')
        ax.axis('off')
    fig.tight_layout()
    plt.show()

def plot_histogram(image):
    fig, axis = plt.subpltos(nrows=1, ncols = 3, figsize=(12,4), sharex=True, sharey=True)
    color_lst = ['red', 'green', 'blue']
    for index, (ax, color) in enumerate(zip(axis, color_lst)):
        ax.set_title('{} histogram'.format(color.title()))
        ax.hist(image[:,:, index].ravel(), bins = 256, color = color, alpha = 0.8)
    fig.tight_layout()
    plt.show()


#Author: Karina Tiemi Kato
from skimage.io import inread, insave

def read_image(path, is_gray = False):
    image = inread(path, as_gray = is_gray)
    return image

def save_image(image, path):
    insave(path, image)


# O Codigo apresentado durante a atividade é de autoria de Karine Kato e fou apresentado com intuito pedagogico
#  Nesta parte do setup devemos inserir as informações gerais sor=bre o pacote
#

from setuptools import setup, find_packages

with open("README.md", "r") as f:
    page_description = f.read()

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

setup(
    name="IMAGE_PROCESSING_PACK",
    version="0.0.4",
    author="Gilcimar Gomes",
    author_email="aguiar.gilcimar@gmail.com",
    description="Version for test, processing to image - Project development by Karina Kato - teacher for DIO",
    long_description=page_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Gil-uai/DIO-Gera-o-Tech-Unimed/tree/main/CAP_02-Python/02_Projetos/Pacotes/IMAGE_PROCESSING_PACK",
    packages=find_packages(),
    install_requires=requirements,
    python_requires='>=3.8',
)